summaryrefslogtreecommitdiffstats
path: root/tests/acceptance
diff options
context:
space:
mode:
authorJan-Christoph Borchardt <hey@jancborchardt.net>2018-06-20 18:13:03 +0200
committerDaniel Calviño Sánchez <danxuliu@gmail.com>2018-06-20 21:40:36 +0200
commit98fb911c03058a3e6e824665f878f73167c5bfd2 (patch)
tree52fd93c4c7d927e62406e2f9d42ac3abe9de420d /tests/acceptance
parent165172dc66e6029f7e7783a2640529d19e17d134 (diff)
Fix wording for 'Leave conversation'
Signed-off-by: Jan-Christoph Borchardt <hey@jancborchardt.net>
Diffstat (limited to 'tests/acceptance')
-rw-r--r--tests/acceptance/features/bootstrap/ConversationListContext.php8
-rw-r--r--tests/acceptance/features/conversation.feature12
2 files changed, 10 insertions, 10 deletions
diff --git a/tests/acceptance/features/conversation.feature b/tests/acceptance/features/conversation.feature
index 2b5c12456..c513eb59e 100644
--- a/tests/acceptance/features/conversation.feature
+++ b/tests/acceptance/features/conversation.feature
@@ -44,12 +44,12 @@ Feature: conversation
And I see that the "admin" conversation is not active
And I see that the number of participants shown in the list is "1"
- Scenario: remove a conversation from the list
+ Scenario: leave a conversation
Given I am logged in
And I have opened the Talk app
And I create a group conversation
And I see that the "You" conversation is active
- When I remove the "You" conversation from the list
+ When I leave the "You" conversation
Then I see that the "You" conversation is not shown in the list
And I see that the "Join a conversation or start a new one" empty content message is shown in the main view
And I see that the sidebar is closed
@@ -79,12 +79,12 @@ Feature: conversation
And I see that the "This conversation has ended" empty content message is shown in the main view
And I see that the sidebar is closed
- Scenario: create a new conversation after removing the active one
+ Scenario: create a new conversation after leaving the active one
Given I am logged in
And I have opened the Talk app
And I create a group conversation
And I see that the "You" conversation is active
- And I remove the "You" conversation from the list
+ And I leave the "You" conversation
And I see that the "You" conversation is not shown in the list
And I see that the "Join a conversation or start a new one" empty content message is shown in the main view
And I see that the sidebar is closed
@@ -95,7 +95,7 @@ Feature: conversation
And I see that the number of participants shown in the list is "1"
And I see that "user0" is shown in the list of participants as a moderator
- Scenario: change to another conversation after removing the active one
+ Scenario: change to another conversation after leaving the active one
Given I am logged in
And I have opened the Talk app
And I create a one-to-one conversation with "admin"
@@ -105,7 +105,7 @@ Feature: conversation
And I see that the "admin" conversation is not active
And I see that the "You" conversation is active
And I see that the number of participants shown in the list is "1"
- And I remove the "You" conversation from the list
+ And I leave the "You" conversation
And I see that the "You" conversation is not shown in the list
And I see that the "Join a conversation or start a new one" empty content message is shown in the main view
And I see that the sidebar is closed
diff --git a/tests/acceptance/features/bootstrap/ConversationListContext.php b/tests/acceptance/features/bootstrap/ConversationListContext.php
index ad6ff3c6a..65c09e977 100644
--- a/tests/acceptance/features/bootstrap/ConversationListContext.php
+++ b/tests/acceptance/features/bootstrap/ConversationListContext.php
@@ -102,8 +102,8 @@ class ConversationListContext implements Context, ActorAwareInterface {
/**
* @return Locator
*/
- public static function removeConversationFromListMenuItemFor($conversation) {
- return self::conversationMenuItemFor($conversation, "Remove conversation from list");
+ public static function leaveConversationMenuItemFor($conversation) {
+ return self::conversationMenuItemFor($conversation, "Leave conversation");
}
/**
@@ -163,11 +163,11 @@ class ConversationListContext implements Context, ActorAwareInterface {
}
/**
* @Given I remove the :conversation conversation from the list
*/
public function iRemoveTheConversationFromTheList($conversation) {
$this->actor->find(self::conversationMenuButtonFor($conversation), 10)->click();
- $this->actor->find(self::removeConversationFromListMenuItemFor($conversation), 2)->click();
+ $this->actor->find(self::leaveConversationMenuItemFor($conversation), 2)->click();
}
/**
@@ -163,11 +163,11 @@ class ConversationListContext implements Context, ActorAwareInterface {
}
/**
- * @Given I remove the :conversation conversation from the list
+ * @Given I leave the :conversation conversation
*/
public function iRemoveTheConversationFromTheList($conversation) {